
dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Crrruel, crrruel, crrruel Captaine Silverrrr...")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Crrruel Captaine Silverrrr...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("Bel ennnnnui !")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn’t it?")
dialogStr("Dangerrrreuse ssssituation, n'est-ce pas ?")


dialogId("k1-pap-sakris", "font_parrot", "Darrrn!")
dialogStr("Malheurrrr!")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("Polly veut un pétard !")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Frappez le, maîtrrre...")


dialogId("ka2-v-nekde", "font_big", "Didn’t we see this somewhere already?")
dialogStr("Nous n'avons pas déjà vu ça quelque part ?")


dialogId("ka2-m-kdepak", "font_small", "No, you’re wrong. This cabin is one hundred and forty four squares larger...")
dialogStr("Non, tu te trompes. Cette cabine est cent quarante quatre carrés plus grande...")


dialogId("ka2-v-papousek", "font_big", "Look at that parrot!!!")
dialogStr("Regarde ce perroquet !!!")


dialogId("ka2-m-kostra", "font_small", "So what? It’s a normal skeleton.")
dialogStr("Et alors, un squelette normal.")


dialogId("ka2-m-posledni", "font_small", "Can you see it? This room is almost the last in the row. Could this really be that treasure?")
dialogStr("Tu as vu ? Cette pièce est quasiment la dernière. Se pourrait-il que se soit vraiment le trésor ?")


dialogId("ka2-v-mapa0", "font_big", "And what would be in the other two?")
dialogStr("Et qu'est ce qu'il y aurait dans les deux autres ?")


dialogId("ka2-v-mapa1", "font_big", "They told us clearly to find the map. Nobody mentioned treasure.")
dialogStr("Ils nous ont clairement dit de trouver la carte. Personne n'a parlé du trésor.")


dialogId("ka2-v-mapa2", "font_big", "Don’t be so annoying. The authors of the game would surely let the player know.")
dialogStr("Ne sois pas si pénible. Les auteurs du jeu voulaient sûrement que le joueur sache.")


dialogId("ka2-m-chapadlo", "font_small", "This octopus has unpleasantly knotted tentacles. I can’t fit between them.")
dialogStr("Ce poulpe a emmêlé ces tentacules de manière désagréable. Je ne peux pas me glisser entre elles.")


dialogId("ka2-v-fik", "font_big", "... so what if we cut one off?!")
dialogStr("... et si nous en coupons une ?!")


dialogId("ka2-v-napad", "font_big", "I am sorry, it was just an idea.")
dialogStr("Désolé, c'était juste une idée.")


dialogId("ka2-m-hej", "font_small", "Little octopus, couldn’t you move away a little bit, please?")
dialogStr("Petit poulpe, pourrais-tu te déplacer un petit peu, s'il te plaît ?")


dialogId("ka2-m-diky", "font_small", "Hmm... thanks a lot.")
dialogStr("Hum... Merci beaucoup.")


dialogId("ka2-v-kostry", "font_big", "Skeletons seem to be a favorite motif of this game authors.")
dialogStr("Les squelettes semblent être le décor favori des auteurs de ce jeu.")


dialogId("ka2-m-patrne", "font_small", "Who are probably living on land. These skeletons are visible proof of their effort to stuff the ocean with all the things that don’t belong there.")
dialogStr("Qui vivent probablement sur terre. Ces squelettes sont la preuve visible de leur effort de bourrer l'océan avec tout ce qui n'a rien à y faire.")


dialogId("ka2-v-myslet", "font_big", "Let’s try to think. Can’t we take our solution of that previous cabin and modify it a little?")
dialogStr("Réfléchissons. Est-ce que nous ne pouvons pas appliquer la solution de la cabine précédente en la modifiant un peu?")


dialogId("ka2-m-tezko", "font_small", "Hmm... I don’t think so.")
dialogStr("Hum... Je ne crois pas.")


dialogId("ka2-m-svitit", "font_small", "So, let’s shed some light on it.")
dialogStr("Alors, faisons un peu de lumière là dessus.")


dialogId("ka2-v-hrbet", "font_big", "My back aches.")
dialogStr("Mon dos me fait mal.")

